# Development Notes

- the command module, will use both filesystem and db to perform actions
- the filesystem module, deals with low-level fs operations
- the db module, deals with database operations
